==> certmanager-model-v1alpha2-6.8.0-sources.jar: io/fabric8/certmanager/api/model/acme/v1alpha2/ACMEChallengeSolverHTTP01IngressTemplateFluent.java <==
package io.fabric8.certmanager.api.model.acme.v1alpha2;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.Object;
import java.lang.String;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class ACMEChallengeSolverHTTP01IngressTemplateFluent<A extends ACMEChallengeSolverHTTP01IngressTemplateFluent<A>> extends BaseFluent<A>{
  public ACMEChallengeSolverHTTP01IngressTemplateFluent() {
  }
  public ACMEChallengeSolverHTTP01IngressTemplateFluent(ACMEChallengeSolverHTTP01IngressTemplate instance) {
    instance = (instance != null ? instance : new ACMEChallengeSolverHTTP01IngressTemplate());

    if (instance != null) {
      this.withMetadata(instance.getMetadata());
      this.withMetadata(instance.getMetadata());
    }
  }
  private ACMEChallengeSolverHTTP01IngressObjectMetaBuilder metadata;
  public ACMEChallengeSolverHTTP01IngressObjectMeta buildMetadata() {
    return this.metadata!=null ?this.metadata.build():null;
  }
  public A withMetadata(ACMEChallengeSolverHTTP01IngressObjectMeta metadata) {
    _visitables.get("metadata").remove(this.metadata);
    if (metadata!=null){ this.metadata= new ACMEChallengeSolverHTTP01IngressObjectMetaBuilder(metadata); _visitables.get("metadata").add(this.metadata);} else { this.metadata = null; _visitables.get("metadata").remove(this.metadata); } return (A) this;
  }
  public boolean hasMetadata() {
    return this.metadata != null;
  }
  public MetadataNested<A> withNewMetadata() {
    return new MetadataNested(null);
  }
  public MetadataNested<A> withNewMetadataLike(ACMEChallengeSolverHTTP01IngressObjectMeta item) {
    return new MetadataNested(item);
  }
  public MetadataNested<A> editMetadata() {
    return withNewMetadataLike(java.util.Optional.ofNullable(buildMetadata()).orElse(null));
  }
  public MetadataNested<A> editOrNewMetadata() {
    return withNewMetadataLike(java.util.Optional.ofNullable(buildMetadata()).orElse(new ACMEChallengeSolverHTTP01IngressObjectMetaBuilder().build()));
  }
  public MetadataNested<A> editOrNewMetadataLike(ACMEChallengeSolverHTTP01IngressObjectMeta item) {
    return withNewMetadataLike(java.util.Optional.ofNullable(buildMetadata()).orElse(item));
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    ACMEChallengeSolverHTTP01IngressTemplateFluent that = (ACMEChallengeSolverHTTP01IngressTemplateFluent) o;
    if (!java.util.Objects.equals(metadata, that.metadata)) return false;

    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(metadata,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (metadata != null) { sb.append("metadata:"); sb.append(metadata); }
    sb.append("}");
    return sb.toString();
  }
  public class MetadataNested<N> extends ACMEChallengeSolverHTTP01IngressObjectMetaFluent<MetadataNested<N>> implements Nested<N>{
    MetadataNested(ACMEChallengeSolverHTTP01IngressObjectMeta item) {
      this.builder = new ACMEChallengeSolverHTTP01IngressObjectMetaBuilder(this, item);
    }
    ACMEChallengeSolverHTTP01IngressObjectMetaBuilder builder;
    public N and() {
      return (N) ACMEChallengeSolverHTTP01IngressTemplateFluent.this.withMetadata(builder.build());
    }
    public N endMetadata() {
      return and();
    }
    
  }
  
}

==> certmanager-model-v1alpha2-6.9.0-sources.jar: io/fabric8/certmanager/api/model/acme/v1alpha2/ACMEChallengeSolverHTTP01IngressTemplateFluent.java <==
package io.fabric8.certmanager.api.model.acme.v1alpha2;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.Object;
import java.lang.String;

/**
 * Generated
 */
@SuppressWarnings("unchecked")
public class ACMEChallengeSolverHTTP01IngressTemplateFluent<A extends ACMEChallengeSolverHTTP01IngressTemplateFluent<A>> extends BaseFluent<A>{
  public ACMEChallengeSolverHTTP01IngressTemplateFluent() {
  }
  
  public ACMEChallengeSolverHTTP01IngressTemplateFluent(ACMEChallengeSolverHTTP01IngressTemplate instance) {
    this.copyInstance(instance);
  }
  private ACMEChallengeSolverHTTP01IngressObjectMetaBuilder metadata;
  
  protected void copyInstance(ACMEChallengeSolverHTTP01IngressTemplate instance) {
    instance = (instance != null ? instance : new ACMEChallengeSolverHTTP01IngressTemplate());
  
    if (instance != null) {
        this.withMetadata(instance.getMetadata());
        this.withMetadata(instance.getMetadata());
      }
  }
  
  public ACMEChallengeSolverHTTP01IngressObjectMeta buildMetadata() {
    return this.metadata!=null ?this.metadata.build():null;
  }
  
  public A withMetadata(ACMEChallengeSolverHTTP01IngressObjectMeta metadata) {
    _visitables.get("metadata").remove(this.metadata);
    if (metadata!=null){ this.metadata= new ACMEChallengeSolverHTTP01IngressObjectMetaBuilder(metadata); _visitables.get("metadata").add(this.metadata);} else { this.metadata = null; _visitables.get("metadata").remove(this.metadata); } return (A) this;
  }
  
  public boolean hasMetadata() {
    return this.metadata != null;
  }
  
  public MetadataNested<A> withNewMetadata() {
    return new MetadataNested(null);
  }
  
  public MetadataNested<A> withNewMetadataLike(ACMEChallengeSolverHTTP01IngressObjectMeta item) {
    return new MetadataNested(item);
  }
  
  public MetadataNested<A> editMetadata() {
    return withNewMetadataLike(java.util.Optional.ofNullable(buildMetadata()).orElse(null));
  }
  
  public MetadataNested<A> editOrNewMetadata() {
    return withNewMetadataLike(java.util.Optional.ofNullable(buildMetadata()).orElse(new ACMEChallengeSolverHTTP01IngressObjectMetaBuilder().build()));
  }
  
  public MetadataNested<A> editOrNewMetadataLike(ACMEChallengeSolverHTTP01IngressObjectMeta item) {
    return withNewMetadataLike(java.util.Optional.ofNullable(buildMetadata()).orElse(item));
  }
  
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    ACMEChallengeSolverHTTP01IngressTemplateFluent that = (ACMEChallengeSolverHTTP01IngressTemplateFluent) o;
    if (!java.util.Objects.equals(metadata, that.metadata)) return false;
  
    return true;
  }
  
  public int hashCode() {
    return java.util.Objects.hash(metadata,  super.hashCode());
  }
  
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (metadata != null) { sb.append("metadata:"); sb.append(metadata); }
    sb.append("}");
    return sb.toString();
  }
  public class MetadataNested<N> extends ACMEChallengeSolverHTTP01IngressObjectMetaFluent<MetadataNested<N>> implements Nested<N>{
    MetadataNested(ACMEChallengeSolverHTTP01IngressObjectMeta item) {
      this.builder = new ACMEChallengeSolverHTTP01IngressObjectMetaBuilder(this, item);
    }
    ACMEChallengeSolverHTTP01IngressObjectMetaBuilder builder;
    
    public N and() {
      return (N) ACMEChallengeSolverHTTP01IngressTemplateFluent.this.withMetadata(builder.build());
    }
    
    public N endMetadata() {
      return and();
    }
    
  
  }

}
